<?php

    if ( ! defined( 'ABSPATH' )  ) { die; }

    /*
     * Set a unique slug-like ID
     */
    $prefix = '_float_any_options';


    CSF::createOptions( $prefix,
        array(

            // display as submenu
            'menu_type'       => 'submenu',
            'menu_parent'     => 'edit.php?post_type=float_any',

            'framework_title' => 'FloatAny ' .esc_html__( 'default settings', 'maxboxy' ),
            'menu_title'      => esc_html__( 'Settings', 'maxboxy' ),
            //'menu_slug'         => 'maxboxy-settings',
            'menu_slug'       => 'settings',
            //'footer_credit'   => 'Float Any <small> v1.0.0</small>',
            'footer_credit'   => ' ',
            'theme'           => 'light',
            'show_bar_menu'   => false,

            // skip menu_icon, coz it's used as a submenu
            //'menu_icon'       => 'dashicons-admin-settings',
            //'menu_icon'       => 'dashicons-schedule',

            //'ajax_save'       => false, // in order for validation to work
            //'save_defaults'   => false, // this must be on default, i.e. 'true' in order to skip printing empty floatany-inline-css
            'output_css'      => false,
            'enqueue_webfont' => false,

    ) );





    /*
     * ================================================================================================
     * VARS
     * ================================================================================================
     */


    function floatany_upgrade_function() {
        //echo '<h2>' .__( 'Need premium features?', 'maxboxy' ) .'</h2>';
        echo '<div style="padding: 0 10px; border-left: 4px solid #339fd4;">' .__( 'Upgrade to ', 'maxboxy') .'<a href="https://maxpressy.com/floatany/" target="_blank">' .__( 'Pro version', 'maxboxy' ) .'</a> to gain access to premium features.</div style="">';
    }


    // replaces the fields available in the pro version
    $empty_field = array(
        'type'      => 'content',
        'content'   => '',
        'class'     => 'floatany-empty-field',
    );

    // You can also add a class to any field to hide it in the future, if there's a need.
    // ...If the Pro version is deactivated, in order to keep its settings,
    // just add the "empty_class" to hide the field when its just the base plugin active
    $empty_class    = array( 'class' => 'floatany-empty-field');

    if ( ! is_multisite() || (is_multisite() && is_main_site()) ) {

        $uninstall_setting = array(
                                'id'        => 'uninstall_setting',
                                'type'      => 'checkbox',
                                'title'     => esc_html__('Uninstall settings if plugin is deleted', 'maxboxy'),
                                'help'      => esc_html__('If this is checked, all Float Any seetings will be deleted when the plugin is removed, otherwise the settings will be preserved.', 'maxboxy'),
        );

    // multisite but not the main site
    } else {

        $uninstall_setting = $empty_field;

    }

// *****



    /*
     * Differentiate options availabe on the basic & the pro version
     */

    // if the pro plugin is active
    if( function_exists( 'floatany_pro_load_textdomain') ) {

        include WP_PLUGIN_DIR .'/maxboxy-float-any/admin/opt/config/options.php';

    // if the pro plugin isn't active
    } else {

        $upgrade_notice = esc_html__('Upgrade to pro version!', 'maxboxy');

        $appear_tab_default = array(

                array(
                    'type'    => 'submessage',
                    'style'   => 'info',
                    'content' => esc_html__('Appearance Settings', 'maxboxy'),
                ),
                array(
                    'type'       => 'notice',
                    'style'      => 'info',
                    'content'    => $upgrade_notice,
                )

            );

    }







    /*
     * ================================================================================================
     * BEGIN OPTIONS
     * ================================================================================================
     */



    /*
     * Opt - General Options
     * ================================================
     */
    CSF::createSection( $prefix, array(
        'title'  => esc_html__( 'General', 'maxboxy'),
        'icon'   => 'fa fa-home',
        'fields' => array(

            array(
                'id'            => 'large_screen_break_point',
                'type'          => 'slider',
                'title'         => esc_html__( 'Large screen breaking point', 'maxboxy' ),
                'help'          => esc_html__( 'From entered point onward, it\'s considered to be the large screen. There are the options that depend on this. Default value is "992".', 'maxboxy' ),
                'default'       => 992,
                'min'           => 200,
                'max'           => 3000,
                'validate'      => 'csf_validate_numeric',
                'sanitize'      => 'absint',

            ),
            array(
                'id'            => 'zindex',
                'type'          => 'number',
                'placeholder'   => 999,
                'title'         => esc_html__( 'Z-index', 'maxboxy' ),
                'help'          => esc_html__( 'If other element is overlapping the box, with "z-index" give a higher priority to the box in a stack order. Default is quite high: 999, most likely you won\'t neet to overwrite it. Still, here you can enter the new default value. Further, you can override that for each panel from its settings.', 'maxboxy' ),
                //'attributes'    => array(
                //    'max'           => 100000,
                //    'min'           => 0,
                //),
            ),

            $uninstall_setting,
      )

    ) );



    /*
     * Opt - Colors tab
     * ================================================
     */
    CSF::createSection( $prefix, array(
        'title'  => esc_html__( 'Colors', 'maxboxy'),
        'icon'   => 'fas fa-palette',
        'fields' => array(

            array(
                'type'      => 'submessage',
                'style'     => 'info',
                'content'   => esc_html__('Colors applied here act as default for FloatAny panels. Further, you can override that for each panel from its settings.', 'maxboxy'),
            ),
            array(
                'id'        => 'panel_popup_bg',
                'type'      => 'background',
                'title'     => esc_html__('Background for the panel', 'maxboxy'),
                'class'     => 'floatany-valid-color',
                'default'   => array(
                                'background-color' => '#e8e2b7',
                ),
            ),
            array(
                'id'        => 'panel_popup_color',
                'type'      => 'color',
                'title'     => esc_html__('Text color in the panel', 'maxboxy'),
                'default'   => '#4b4b4b',
                'class'     => 'floatany-valid-color',
            ),

            array(
                'type'      => 'subheading',
                'content'   => esc_html__( 'Close/toggle button', 'float-any' ),
            ),
            array(
                'id'        => 'panel_shut_bg',
                'type'      => 'color',
                'title'     => esc_html__('Toggler/closer background', 'maxboxy'),
                'default'   => '#333333',
                'class'     => 'floatany-valid-color',
            ),
            array(
                'id'        => 'panel_shut_color',
                'type'      => 'color',
                'title'     => esc_html__('Toggler/closer color', 'maxboxy'),
                'default'   => '#ffffff',
                'class'     => 'floatany-valid-color',
            ),

        )

    ) );



    /*
     * Opt - Appear tab
     * ================================================
     */
    CSF::createSection( $prefix, array(
        'title'  => esc_html__( 'Appear', 'maxboxy'),
        'icon'   => 'far fa-eye',
        'fields' => $appear_tab_default,

    ) );



    // if the pro plugin is active
    if( ! function_exists( 'floatany_pro_load_textdomain') ) {

        /*
         * Opt - Upgrade tab
         * ================================================
         */
        CSF::createSection( $prefix, array(
            'title'  => esc_html__( 'Upgrade', 'maxboxy'),
            'icon'   => 'fas fa-sign-in-alt',
            'fields' => array(

                    array(
                        'type'      => 'callback',
                        'function'  => 'floatany_upgrade_function',
                    ),

            )

        ) );

    }
